Package: gpciIntCensor
Type: Package
Title: Generalized Process Capability Indices for Interval-Censored
        Data
Version: 0.1.0
Authors@R: c(
    person("Shikhar", "Tyagi",
           email = "shikhar1093tyagi@gmail.com",
           role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-1606-0844")),
    person("Sumit", "Kumar",
           email = "stats.sumitbhal@gmail.com",
           role = "aut"),
    person("Arvind", "Pandey",
           email = "arvindmzu@gmail.com",
           role = "aut"),
    person("Bhupendra", "Singh",
           email = "bhupendra.rana@gmail.com",
           role = "aut"),
    person("Vrijesh", "Tripathi",
           email = "vrijesh.tripathi@uwi.edu",
           role = "aut")
    )
Description: A comprehensive framework for computing, estimating, and validating 
    Generalized Process Capability Indices (GPCIs) under interval-censored data. 
    Supports user-supplied probability density functions (PDF/PMF), cumulative 
    distribution functions (CDF), and survival functions (SF). Parameter estimation 
    is performed using Maximum Likelihood Estimation for interval-censored data via 
    the MleCensoR package. Computes classical and generalized capability indices 
    including Cpy (Maiti et al., 2010), Spmk (Dey & Saha, 2019), CpTk (Saha et al., 
    2019), Cpc (Saha et al., 2022), CNpmc (Alotaibi et al., 2022), CNpmkc (Saha et 
    al., 2024), CNpk (Saha et al., 2018), and Vannman's Cp(u,v) family. Provides 
    parametric and non-parametric bootstrap confidence intervals at 90%, 95%, and 99% 
    confidence levels using percentile, normal, basic, BCa, BCp, and studentized 
    bootstrap methods. Computes standard errors, mean squared errors, and coverage 
    probabilities for both distribution parameters and capability indices.
    References:
    Maiti, Saha & Nanda (2010) <doi:10.1080/16843703.2010.11673233>,
    Saha, Dey & Maiti (2018) <doi:10.1080/21681015.2018.1437793>,
    Dey & Saha (2019) <doi:10.1007/s41872-019-00081-4>,
    Saha, Dey & Maiti (2019) <doi:10.1007/s13198-019-00789-7>,
    Alotaibi, Dey & Saha (2022) <doi:10.1155/2022/3135264>,
    Saha, Dey & Nadarajah (2022) <doi:10.1080/02664763.2021.1971632>,
    Saha, Tripathi & Dey (2024) <doi:10.1142/S021853932450013X>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.0.0)
Imports: stats, graphics, numDeriv, boot, MleCensoR
Suggests: testthat (>= 3.0.0), knitr, rmarkdown
VignetteBuilder: knitr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-08-03 19:18:25 UTC; shikhar tyagi
Author: Shikhar Tyagi [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1606-0844>),
  Sumit Kumar [aut],
  Arvind Pandey [aut],
  Bhupendra Singh [aut],
  Vrijesh Tripathi [aut]
Maintainer: Shikhar Tyagi <shikhar1093tyagi@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-08 13:00:02 UTC
