# Generated by roxygen2: do not edit by hand

S3method(autoplot,gpci_ci_censor)
S3method(autoplot,gpci_diagnostics_censor)
S3method(autoplot,gpcifit_censor)
S3method(coef,gpcifit_censor)
S3method(confint,gpcifit_censor)
S3method(plot,gpci_ci_censor)
S3method(plot,gpci_diagnostics_censor)
S3method(plot,gpcifit_censor)
S3method(print,gpci_ci_censor)
S3method(print,gpci_diagnostics_censor)
S3method(print,gpcifit_censor)
S3method(summary,gpci_ci_censor)
S3method(summary,gpci_diagnostics_censor)
S3method(summary,gpcifit_censor)
S3method(vcov,gpcifit_censor)
export(autoplot)
export(boot_ci_censor)
export(capability_censor)
export(compute_diagnostics_censor)
export(compute_theoretical_moments_censor)
export(define_distribution_censor)
export(dist_beta)
export(dist_gamma)
export(dist_logistic_exponential)
export(dist_lognormal)
export(dist_normal)
export(dist_weibull)
export(fit_distribution_censor)
export(gpci_boot_censor)
export(gpci_diagnostics_censor)
export(gpci_dist_censor)
export(gpci_fit_censor)
export(gpci_index)
importFrom(MleCensoR,mle_interval)
importFrom(boot,boot)
importFrom(boot,boot.ci)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(numDeriv,grad)
importFrom(numDeriv,hessian)
importFrom(stats,dbeta)
importFrom(stats,dgamma)
importFrom(stats,dlnorm)
importFrom(stats,dnorm)
importFrom(stats,dweibull)
importFrom(stats,integrate)
importFrom(stats,nlminb)
importFrom(stats,optim)
importFrom(stats,pbeta)
importFrom(stats,pgamma)
importFrom(stats,plnorm)
importFrom(stats,pnorm)
importFrom(stats,pweibull)
importFrom(stats,qbeta)
importFrom(stats,qgamma)
importFrom(stats,qlnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,qweibull)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,uniroot)
importFrom(stats,var)
importFrom(utils,globalVariables)
