% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot.gpcifit_censor}
\alias{plot.gpcifit_censor}
\title{Plot Method for gpcifit_censor Objects}
\usage{
\method{plot}{gpcifit_censor}(x, main = "Process Capability Analysis (Interval-Censored)", ...)
}
\arguments{
\item{x}{An object of class \code{gpcifit_censor}.}

\item{main}{Title of the plot.}

\item{...}{Additional graphical parameters.}
}
\value{
Invisible fit object \code{x}.
}
\description{
Visualizes interval-censored observations, fitted distribution density curve, and specification limits.
}
\examples{
dist_norm <- dist_normal()
left <- c(9.5, 10.2, 8.8, 11.1, 9.9)
right <- c(10.5, 11.2, 9.8, 12.1, 10.9)
fit <- capability_censor(left, right, dist_norm, USL = 13, LSL = 7)
plot(fit)
}
