% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{autoplot}
\alias{autoplot}
\alias{autoplot.gpcifit_censor}
\alias{autoplot.gpci_ci_censor}
\alias{autoplot.gpci_diagnostics_censor}
\title{Autoplot Generic and Methods for Compatibility}
\usage{
autoplot(object, ...)

\method{autoplot}{gpcifit_censor}(object, ...)

\method{autoplot}{gpci_ci_censor}(object, ...)

\method{autoplot}{gpci_diagnostics_censor}(object, ...)
}
\arguments{
\item{object}{Object to plot.}

\item{...}{Additional arguments.}
}
\value{
Invisible plot object.
}
\description{
Autoplot Generic and Methods for Compatibility
}
\examples{
dist_norm <- dist_normal()
left <- c(9.5, 10.2, 8.8, 11.1, 9.9)
right <- c(10.5, 11.2, 9.8, 12.1, 10.9)
fit <- capability_censor(left, right, dist_norm, USL = 13, LSL = 7)
autoplot(fit)
}
