% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot.gpci_ci_censor}
\alias{plot.gpci_ci_censor}
\title{Plot Method for gpci_ci_censor Objects}
\usage{
\method{plot}{gpci_ci_censor}(x, ...)
}
\arguments{
\item{x}{An object of class \code{gpci_ci_censor}.}

\item{...}{Additional graphical parameters.}
}
\value{
Invisible CI object \code{x}.
}
\description{
Visualizes bootstrap confidence intervals across different significance levels.
}
\examples{
\donttest{
dist_norm <- dist_normal()
left <- c(9.5, 10.2, 8.8, 11.1, 9.9)
right <- c(10.5, 11.2, 9.8, 12.1, 10.9)
fit <- capability_censor(left, right, dist_norm, USL = 13, LSL = 7)
ci <- boot_ci_censor(fit, B = 100, alpha = c(0.10, 0.05, 0.01), method = "percentile")
plot(ci)
}
}
