% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{define_distribution_censor}
\alias{define_distribution_censor}
\alias{gpci_dist_censor}
\title{Define a Process Distribution for Interval-Censored Data}
\usage{
define_distribution_censor(
  name,
  pdf = NULL,
  cdf = NULL,
  sf = NULL,
  quantile = NULL,
  params = list(),
  support = c(-Inf, Inf)
)

gpci_dist_censor(
  name,
  pdf = NULL,
  cdf = NULL,
  sf = NULL,
  quantile = NULL,
  params = list(),
  support = c(-Inf, Inf)
)
}
\arguments{
\item{name}{Character string naming the distribution.}

\item{pdf}{Function representing the probability density function (PDF/PMF).}

\item{cdf}{Function representing the cumulative distribution function (CDF).}

\item{sf}{Function representing the survival function (SF = 1 - CDF).}

\item{quantile}{Function representing the quantile function.}

\item{params}{Named list of parameters for the distribution.}

\item{support}{Vector of length 2 defining lower and upper bounds of support.}
}
\value{
An object of class \code{gpci_dist_censor}.
}
\description{
Constructor to define a probability distribution for process capability analysis
under interval-censored data.
}
\examples{
custom_weib <- define_distribution_censor(
  name = "custom_weibull",
  sf = function(x, shape, scale) pweibull(x, shape, scale, lower.tail = FALSE),
  params = list(shape = 2, scale = 10),
  support = c(0, Inf)
)
}
