% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/indices.R
\name{gpci_index}
\alias{gpci_index}
\title{Dispatcher for Single Index Computation under Interval Censoring}
\usage{
gpci_index(fit, index)
}
\arguments{
\item{fit}{A \code{gpcifit_censor} object.}

\item{index}{Name of index to compute.}
}
\value{
Numeric value of the specified index.
}
\description{
Dispatcher for Single Index Computation under Interval Censoring
}
\examples{
dist_norm <- dist_normal()
left <- c(9.5, 10.2, 8.8, 11.1, 9.9)
right <- c(10.5, 11.2, 9.8, 12.1, 10.9)
fit <- capability_censor(left, right, dist_norm, USL = 13, LSL = 7)
gpci_index(fit, "Cpy")
}
