% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{builtin_dist}
\alias{builtin_dist}
\alias{dist_normal}
\alias{dist_lognormal}
\alias{dist_gamma}
\alias{dist_weibull}
\alias{dist_beta}
\alias{dist_logistic_exponential}
\title{Built-in Process Distributions for Interval-Censored Analysis}
\usage{
dist_normal(mean = 0, sd = 1)

dist_lognormal(meanlog = 0, sdlog = 1)

dist_gamma(shape = 1, scale = 1)

dist_weibull(shape = 1, scale = 1)

dist_beta(shape1 = 1, shape2 = 1)

dist_logistic_exponential(shape = 1, scale = 1)
}
\arguments{
\item{mean, sd}{Mean and standard deviation parameters for normal distribution.}

\item{meanlog, sdlog}{Mean and standard deviation of the distribution on the log scale.}

\item{shape, scale}{Shape and scale parameters.}

\item{shape1, shape2}{Non-negative parameters of the Beta distribution.}
}
\value{
An object of class \code{gpci_dist_censor}.
}
\description{
Convenience constructors for standard process probability distributions.
}
\examples{
dist_n <- dist_normal(mean = 10, sd = 2)
dist_le <- dist_logistic_exponential(shape = 1.5, scale = 0.5)
}
