% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/distribution.R
\name{compute_theoretical_moments_censor}
\alias{compute_theoretical_moments_censor}
\title{Compute Theoretical Moments of an Interval-Censored Distribution}
\usage{
compute_theoretical_moments_censor(dist)
}
\arguments{
\item{dist}{A \code{gpci_dist_censor} object.}
}
\value{
A list with \code{mean} and \code{var}.
}
\description{
Computes the theoretical mean and variance of a \code{gpci_dist_censor} object using numerical integration.
}
\examples{
dist_n <- dist_normal(mean = 5, sd = 1.5)
compute_theoretical_moments_censor(dist_n)
}
